import { Host, h } from "@stencil/core";
import { IcInformationStatus, } from "../../utils/types";
import successIcon from "../../assets/success-icon.svg";
import { removeDisabledFalse, renderDynamicChildSlots, slotHasContent, } from "../../utils/helpers";
/**
 * @slot left-icon - Content will be placed to the left of the input.
 */
export class InputComponentContainer {
    constructor() {
        /**
         *  If `true`, the disabled state will be set.
         */
        this.disabled = false;
        /**
         *  If `true`, the input component container will fill the width of the container it is in.
         */
        this.fullWidth = false;
        /**
         *  If `true`, the input component container will allow for multiple lines.
         */
        this.multiLine = false;
        /**
         *  If `true`, the readonly state will be set.
         */
        this.readonly = false;
        /**
         * The size of the input component container component.
         */
        this.size = "medium";
        /**
         *  If `true`, the validation will display inline.
         */
        this.validationInline = false;
        /**
         * The validation status of the input component container - e.g. 'error' | 'warning' | 'success'.
         */
        this.validationStatus = "";
    }
    watchDisabledHandler() {
        removeDisabledFalse(this.disabled, this.el);
    }
    componentWillLoad() {
        removeDisabledFalse(this.disabled, this.el);
    }
    componentDidLoad() {
        this.hostMutationObserver = new MutationObserver((mutationList) => renderDynamicChildSlots(mutationList, "left-icon", this));
        this.hostMutationObserver.observe(this.el, { childList: true });
    }
    render() {
        const { size, validationStatus, disabled, readonly, multiLine, fullWidth, validationInline, } = this;
        return (h(Host, { key: '3349803b2fc3756e616a3e6e9f88439c3d360897', class: {
                [`ic-input-component-container-${size}`]: true,
                [`ic-input-component-container-${validationStatus}`]: validationStatus !== "" && !disabled && !readonly,
                "ic-input-component-container-disabled": !!disabled,
                "ic-input-component-container-readonly": !!readonly,
                "ic-input-component-container-multiline": !!multiLine,
                "ic-input-component-container-full-width": !!fullWidth,
            }, "aria-disabled": disabled ? "true" : null }, h("div", { key: 'bf85d48b1507e4c7d8394e067314e383e77ffb72', class: "focus-indicator" }, slotHasContent(this.el, "left-icon") && (h("div", { key: '7660d9c72526a8bf34e88488884933cc7a5a96cd', class: "icon-container" }, h("slot", { key: 'dc31f454f708ecbcf821cb94cf4d8b5b354d149f', name: "left-icon" }))), h("slot", { key: '92265e4967394e33cdf8763bd8c8b433dbe0536e' }), validationInline &&
            validationStatus === IcInformationStatus.Success && (h("span", { key: 'ecefbb2eaf920a2300bb9a30e20c18a86754fba0', class: "inline-success", innerHTML: successIcon })))));
    }
    static get is() { return "ic-input-component-container"; }
    static get originalStyleUrls() {
        return {
            "$": ["ic-input-component-container.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["ic-input-component-container.css"]
        };
    }
    static get properties() {
        return {
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "If `true`, the disabled state will be set."
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false,
                "defaultValue": "false"
            },
            "fullWidth": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "If `true`, the input component container will fill the width of the container it is in."
                },
                "getter": false,
                "setter": false,
                "attribute": "full-width",
                "reflect": false,
                "defaultValue": "false"
            },
            "multiLine": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "If `true`, the input component container will allow for multiple lines."
                },
                "getter": false,
                "setter": false,
                "attribute": "multi-line",
                "reflect": false,
                "defaultValue": "false"
            },
            "readonly": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "If `true`, the readonly state will be set."
                },
                "getter": false,
                "setter": false,
                "attribute": "readonly",
                "reflect": false,
                "defaultValue": "false"
            },
            "size": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcSizes",
                    "resolved": "\"large\" | \"medium\" | \"small\" | undefined",
                    "references": {
                        "IcSizes": {
                            "location": "import",
                            "path": "../../utils/types",
                            "id": "src/utils/types.ts::IcSizes"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The size of the input component container component."
                },
                "getter": false,
                "setter": false,
                "attribute": "size",
                "reflect": false,
                "defaultValue": "\"medium\""
            },
            "validationInline": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "If `true`, the validation will display inline."
                },
                "getter": false,
                "setter": false,
                "attribute": "validation-inline",
                "reflect": false,
                "defaultValue": "false"
            },
            "validationStatus": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcInformationStatusOrEmpty",
                    "resolved": "\"\" | \"error\" | \"success\" | \"warning\" | undefined",
                    "references": {
                        "IcInformationStatusOrEmpty": {
                            "location": "import",
                            "path": "../../utils/types",
                            "id": "src/utils/types.ts::IcInformationStatusOrEmpty"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The validation status of the input component container - e.g. 'error' | 'warning' | 'success'."
                },
                "getter": false,
                "setter": false,
                "attribute": "validation-status",
                "reflect": false,
                "defaultValue": "\"\""
            }
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "disabled",
                "methodName": "watchDisabledHandler"
            }];
    }
}
//# sourceMappingURL=ic-input-component-container.js.map
