import { Host, h, } from "@stencil/core";
import { getSlot, getSlotContent, isSlotUsed } from "../../utils/helpers";
const NAV_GROUP_TAG = "IC-NAVIGATION-GROUP";
const NAV_ITEM_TAG = "IC-NAVIGATION-ITEM";
/**
 * @slot navigation - Content will be rendered at top of panel.
 * @slot buttons - Content will be rendered above version info and below navigation.
 */
export class NavigationMenu {
    constructor() {
        this.hasButtons = false;
        this.hasNavigation = false;
        this.lastTabStop = null;
        this.navGroupFirst = false;
        this.navItemAboveButtons = false;
        /**
         * The status info to display.
         */
        this.status = "";
        /**
         * Sets the theme color to the dark or light theme color. "inherit" will set the color based on the system settings or ic-theme component.
         */
        this.theme = "inherit";
        /**
         * The version info to display.
         */
        this.version = "";
        this.setLastTabStop = (lastNavGroupExpanded) => {
            let lastEl = this.navigationEls[this.navigationEls.length - 1];
            if (lastEl.tagName === NAV_GROUP_TAG && lastNavGroupExpanded) {
                const childNavItems = lastEl.children;
                lastEl = childNavItems[childNavItems.length - 1];
            }
            if (lastEl.tagName === NAV_ITEM_TAG) {
                //check for slotted content i.e. react router link
                const slotContent = getSlot(lastEl, "navigation-item");
                if (slotContent !== null) {
                    lastEl = slotContent;
                }
            }
            this.lastTabStop = lastEl;
        };
        this.closeMenu = () => {
            this.icNavigationMenuClose.emit();
        };
        this.focusCloseButton = () => {
            var _a;
            (_a = this.closeButton) === null || _a === void 0 ? void 0 : _a.focus();
        };
        this.focusLastTabStop = () => {
            let focusEl;
            if (this.lastTabStop !== null) {
                switch (this.lastTabStop.tagName) {
                    case "IC-NAVIGATION-BUTTON":
                    case NAV_ITEM_TAG:
                    case NAV_GROUP_TAG:
                        focusEl = this.lastTabStop;
                        focusEl.focus();
                        break;
                    case "A":
                        this.lastTabStop.focus();
                        break;
                }
            }
        };
    }
    componentWillLoad() {
        this.navBarEl = document.querySelector("ic-top-navigation");
        this.navigationEls = getSlotContent(this.el, "navigation");
        if (this.navigationEls) {
            this.hasNavigation = true;
            const lastEl = this.navigationEls[this.navigationEls.length - 1];
            if (lastEl.tagName === NAV_ITEM_TAG) {
                this.navItemAboveButtons = true;
            }
            else if (lastEl.tagName === NAV_GROUP_TAG) {
                lastEl.addEventListener("navigationGroupExpanded", ((event) => {
                    this.setLastTabStop(event.detail.expanded);
                }));
            }
            const firstEl = this.navigationEls[0];
            if (firstEl.tagName === NAV_GROUP_TAG) {
                this.navGroupFirst = true;
            }
        }
        const buttonContent = getSlotContent(this.el, "buttons");
        if (buttonContent !== null) {
            this.hasButtons = true;
            this.lastTabStop = buttonContent[buttonContent.length - 1];
        }
        else {
            if (this.hasNavigation && this.navigationEls) {
                this.setLastTabStop(false);
            }
        }
    }
    componentDidLoad() {
        this.focusCloseButton();
    }
    componentWillRender() {
        this.hasNavigation = isSlotUsed(this.el, "navigation");
        this.hasButtons = isSlotUsed(this.el, "buttons");
    }
    navItemClickHandler() {
        this.closeMenu();
    }
    handleKeyDown(ev) {
        if (ev.key === "Tab") {
            if (ev.shiftKey) {
                if (document.activeElement === this.navBarEl) {
                    ev.preventDefault();
                    this.focusLastTabStop();
                }
            }
            else if (document.activeElement === this.lastTabStop ||
                this.lastTabStop === null) {
                ev.preventDefault();
                this.focusCloseButton();
            }
        }
        else if (ev.key === "Escape") {
            this.closeMenu();
        }
    }
    render() {
        return (h(Host, { key: 'd37a801a1b4c312fb3d1e301150ce4b731b8e378', class: { [`ic-theme-${this.theme}`]: this.theme !== "inherit" } }, h("div", { key: 'e243034b5ec260c946217f411c4c0c56773a3ff0', class: "popout-modal", onClick: this.closeMenu }), h("div", { key: '3958153a358974fa0ba7260f985ca48bbe010a5d', class: "popout-menu", role: "dialog", "aria-modal": "true", "aria-label": `${this.hasNavigation ? "Navigation" : "App"} menu` }, h("span", { key: 'ec3a59243f6fe8bc839f09cf6cb23013f1258cc0', "aria-hidden": "true", id: "navigation-landmark-text", class: "navigation-landmark-text" }, "Main navigation"), h("nav", { key: 'f0fe76cf4eeec54e3382344abec7fe80b6ab5ba5', "aria-labelledby": "navigation-landmark-text", "aria-hidden": this.hasNavigation ? "false" : "true" }, h("div", { key: '246f1b43500b11e0ec9b133030c79f140b5aacd3', class: {
                ["menu-close-button-container"]: true,
                ["nav-group-first"]: this.navGroupFirst,
            } }, h("ic-button", { key: 'c836f86ad0ca67841cca01b8a6717d78982163ed', ref: (el) => (this.closeButton = el), id: "menu-close-button", class: "menu-close-button", variant: "icon", size: "large", "aria-label": `Close ${this.hasNavigation ? "navigation" : "app"} menu`, onClick: this.closeMenu }, h("svg", { key: 'd7524666b3f08ed7ab9ece6b33843fab72e521d7', width: "14", height: "14", viewBox: "0 0 14 14", fill: "none", xmlns: "http://www.w3.org/2000/svg" }, h("path", { key: 'd659007ab35980d78395c7acbc2a34f333108d68', d: "M14 1.41L12.59 0L7 5.59L1.41 0L0 1.41L5.59 7L0 12.59L1.41 14L7 8.41L12.59 14L14 12.59L8.41 7L14 1.41Z" })))), this.hasNavigation && h("slot", { key: '4067b296fb1eade8a35e62340be0b682faeebf0c', name: "navigation" })), this.hasButtons && (h("div", { key: '6020b1dea12858619b1c4e42a9c28829ce9d926b', class: {
                ["menu-buttons-container"]: true,
                ["menu-buttons-container-nav-item-above"]: this.navItemAboveButtons,
            } }, h("slot", { key: '751e587cc503a8db8a668a8ca2335da12893e459', name: "buttons" }))), (this.status !== "" || this.version !== "") && (h("div", { key: 'e368dacc5061176d89f726b891cc5cc2f3913b9d', class: {
                ["menu-status-version-container"]: true,
                ["status-version-no-buttons"]: !this.hasButtons,
            } }, this.status !== "" && (h("div", { key: '7745d4b718c9644598220a5625a260995d195ce1', class: "menu-status" }, h("ic-typography", { key: '448b1a0d774fd9ffda795969c2184539e6d13ee3', variant: "label-uppercase", "aria-label": "app tag", class: "menu-status-text" }, this.status))), this.version !== "" && (h("div", { key: '79a7a1467b334acf390661808a7c0eb9bbedcd6e', class: "menu-version" }, h("ic-typography", { key: '87cc4741151c42401646094fb3ae20bc6efbc54d', variant: "label", class: "menu-version-text", "aria-label": "app version" }, this.version))))))));
    }
    static get is() { return "ic-navigation-menu"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["ic-navigation-menu.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["ic-navigation-menu.css"]
        };
    }
    static get properties() {
        return {
            "status": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The status info to display."
                },
                "getter": false,
                "setter": false,
                "attribute": "status",
                "reflect": false,
                "defaultValue": "\"\""
            },
            "theme": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcThemeMode",
                    "resolved": "\"dark\" | \"inherit\" | \"light\" | undefined",
                    "references": {
                        "IcThemeMode": {
                            "location": "import",
                            "path": "../../utils/types",
                            "id": "src/utils/types.ts::IcThemeMode"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Sets the theme color to the dark or light theme color. \"inherit\" will set the color based on the system settings or ic-theme component."
                },
                "getter": false,
                "setter": false,
                "attribute": "theme",
                "reflect": false,
                "defaultValue": "\"inherit\""
            },
            "version": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The version info to display."
                },
                "getter": false,
                "setter": false,
                "attribute": "version",
                "reflect": false,
                "defaultValue": "\"\""
            }
        };
    }
    static get events() {
        return [{
                "method": "icNavigationMenuClose",
                "name": "icNavigationMenuClose",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "- Emitted when the menu is closed."
                        }],
                    "text": ""
                },
                "complexType": {
                    "original": "void",
                    "resolved": "void",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "el"; }
    static get listeners() {
        return [{
                "name": "navItemClicked",
                "method": "navItemClickHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "keydown",
                "method": "handleKeyDown",
                "target": "document",
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=ic-navigation-menu.js.map
