import { Host, h } from "@stencil/core";
import checkIcon from "../../assets/check-icon.svg";
import warningIcon from "../../assets/warning-icon-outline.svg";
import { isPropDefined } from "../../utils/helpers";
export class Step {
    constructor() {
        /**
         * @internal If `true`, and a compact stepper  is being used, the current step will be the only step in view.
         */
        this.current = false;
        /**
         * @internal Sets the theme color to the dark or light theme color. "inherit" will set the color based on the system settings or ic-theme component.
         */
        this.theme = "inherit";
        /**
         * The state of the step within the stepper.
         */
        this.type = "active";
    }
    typeChangeHandler() {
        if (this.variant === "compact" && this.type === "current") {
            this.current = true;
        }
        else {
            this.current = false;
        }
    }
    render() {
        var _a, _b;
        // ARIA LABEL
        let ariaLabel = "";
        if (this.type === "completed") {
            ariaLabel = ". Completed step";
        }
        else if (this.type === "disabled") {
            ariaLabel = ". Non-required step";
        }
        else if (this.status === "required") {
            ariaLabel = ". Required step";
        }
        else if (this.status === "optional") {
            ariaLabel = ". Optional step";
        }
        // STEP STATUS
        let stepStatus;
        if (this.status && isPropDefined(this.status)) {
            stepStatus = this.status[0].toUpperCase() + this.status.slice(1);
        }
        // STEP TYPE
        let stepType;
        if (this.type === "disabled" || this.compactStepStyling === "disabled") {
            stepType = "Not required";
        }
        else if (this.compactStepStyling === "completed") {
            stepType = "Completed";
        }
        // STATUS ICON FOR COMPACT STEP
        let statusIcon;
        if (this.type === "completed" || this.compactStepStyling === "completed") {
            statusIcon = (h("span", { key: '4a9203e6aa1fd036fb787b0157742238663bcbd5', class: "check-icon step-icon", "aria-hidden": "true", innerHTML: checkIcon }));
        }
        else if (this.type === "disabled" ||
            this.compactStepStyling === "disabled") {
            statusIcon = (h("span", { key: '3e6f50e3f85e96b40066233cf8f579eeb2915a4a', class: "warning-icon step-icon", "aria-hidden": "true", innerHTML: warningIcon }));
        }
        // COMPACT STEP COMPONENT
        const compactStep = (h("div", { key: 'e0176afedd5e4d78e9cf0cf3b9127fb350d37230', class: {
                ["step"]: true,
                ["current"]: !!this.current,
                [`compact-step-${this.compactStepStyling}`]: !!this.compactStepStyling,
                ["disabled"]: this.type === "disabled" || this.compactStepStyling === "disabled",
            } }, h("ic-loading-indicator", { key: '35b1cdf3892123ba853ca17b1442f40a4b769674', class: {
                "compact-step-progress-indicator": true,
                "not-required": this.type === "disabled" ||
                    this.compactStepStyling === "disabled",
            }, "aria-hidden": "true", size: "small", "inner-label": this.stepNum, progress: this.progress }), h("div", { key: '6280811d6995b9a06c2a758a2e27a8b4c50f6a3c', class: "heading-area" }, h("ic-typography", { key: '44382dd1f5a00d397f857341d4c85c35fe3986b0', variant: "h4", class: "heading" }, this.heading), h("div", { key: '80897d2a2b10a74e4effe62b37e1f991041d98d0', class: "info-line" }, h("ic-typography", { key: 'a8fb18daae6c067825f7251a02dc0a43c4d8be00', variant: "caption", class: "step-num" }, `${this.stepNum} of ${this.lastStepNum}`, h("span", { key: '7fec868e706c5ae8500e5f62bd40e06f207f27bc', class: "visually-hidden" }, " steps")), (this.subheading ||
            this.type === "completed" ||
            this.type === "disabled" ||
            (this.variant === "compact" &&
                !!this.compactStepStyling &&
                this.compactStepStyling !== "active") ||
            !!this.status) && (h("div", { key: '2686329ae67e2d4e5ff70269c53111e51e40e22d', class: "step-status" }, statusIcon !== undefined && statusIcon, (this.subheading || stepType) && (h("ic-typography", { key: '9d084452fe5fc69f3fb75d23e52cafaab618cc76', variant: "caption" }, this.subheading !== null && isPropDefined(this.subheading)
            ? this.subheading
            : this.type === "disabled" ||
                (this.variant === "compact" &&
                    this.compactStepStyling === "disabled") ||
                this.type === "completed" ||
                (this.variant === "compact" &&
                    this.compactStepStyling === "completed")
                ? stepType
                : this.status && stepStatus))))), this.lastStep ? (h("ic-typography", { variant: "subtitle-small", class: "next-step" }, "Last step")) : (isPropDefined(this.nextStepHeading) && (h("ic-typography", { variant: "subtitle-small", class: "next-step" }, "Next", h("span", { class: "visually-hidden" }, " step is"), ":", " ", this.nextStepHeading))))));
        // ICON FOR DEFAULT STEP
        let icon;
        if (this.type !== "completed") {
            icon = (h("ic-typography", { key: '40a724fa1fd9fb124824b86c77f0e8e579e10ddf', variant: "subtitle-small" }, h("span", { key: '80d7cee87c798fd31ef259c60cdc0207d1149569', class: "step-icon-inner", "aria-hidden": "true" }, this.stepNum)));
        }
        else {
            icon = (h("div", { key: 'af64e8626ca32695d539a300549709505f5e0074', class: "step-icon-inner", "aria-hidden": "true" }, h("span", { key: 'ae8e6c0527c288eb8cba12ee407ba95b30518ef3', class: "check-icon", innerHTML: checkIcon })));
        }
        // STEP CONNECT FOR DEFAULT STEP
        const partialBar = this.type === "current" && (h("div", { key: '36d5a9fa668901e1e975222a8b675330af53761d', class: "step-connect-inner" }));
        const finalStep = !this.lastStep && (h("div", { key: '5326ee2373d2580f2ba5d41547a50b0c59ad31e6', class: {
                ["step-connect"]: true,
                ["aligned-full-width"]: !!(((_a = this.el.parentElement) === null || _a === void 0 ? void 0 : _a.classList.contains("ic-stepper-default")) &&
                    !this.el.parentElement.classList.contains("ic-stepper-aligned-left")),
            } }, partialBar));
        // DEFAULT STEP COMPONENT
        const defaultStep = (h("div", { key: 'de6aef5add716f0ab39f01025252963f93ff87db', class: {
                ["step"]: true,
                [`${this.type}`]: true,
            } }, h("div", { key: '1c4948393db6d357dddd34ede57e4f85525904e1', class: "step-top" }, h("div", { key: '9a5fbf343c17dbf1426a8d81f7b35964f2ebe384', class: "step-icon" }, icon), finalStep), (this.heading || this.subheading || this.status) && (h("div", { key: 'e9f4545dd4490ad1a7c1cc786c2339c9b097ba2b', class: "heading-area" }, this.heading && (h("ic-typography", { key: 'e26a94db6d7e199eced26ec78b8997641652d77a', variant: "subtitle-large", class: "heading" }, this.heading)), this.heading && (this.subheading || this.status) && (h("ic-typography", { key: 'a30708b8b2c1a7fc37d90b69426f88e794a4e9fb', variant: "caption", class: "subheading" }, this.subheading !== null && isPropDefined(this.subheading)
            ? this.subheading
            : stepStatus))))));
        return (h(Host, { key: 'b7faa59fe0e1e1315ff7753bcba19a24bc671368', role: "listitem", "aria-label": `Step ${this.stepNum}${ariaLabel}`, "aria-current": (this.current || this.type === "current") && "step", class: {
                ["aligned-full-width"]: !!(((_b = this.el.parentElement) === null || _b === void 0 ? void 0 : _b.classList.contains("ic-stepper-default")) &&
                    !this.el.parentElement.classList.contains("ic-stepper-aligned-left")),
                [`ic-step-${this.variant}`]: true,
                [`ic-theme-${this.theme}`]: this.theme !== "inherit",
            } }, this.variant === "compact" ? compactStep : defaultStep));
    }
    static get is() { return "ic-step"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["ic-step.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["ic-step.css"]
        };
    }
    static get properties() {
        return {
            "compactStepStyling": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcStepTypes",
                    "resolved": "\"active\" | \"completed\" | \"current\" | \"disabled\" | undefined",
                    "references": {
                        "IcStepTypes": {
                            "location": "import",
                            "path": "./ic-step.types",
                            "id": "src/components/ic-step/ic-step.types.ts::IcStepTypes"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "If a compact stepper is being used, this sets the styling of the step."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "compact-step-styling",
                "reflect": false
            },
            "current": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "If `true`, and a compact stepper  is being used, the current step will be the only step in view."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "current",
                "reflect": false,
                "defaultValue": "false"
            },
            "lastStep": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "If `true`, the step will be marked as being the last one in the series. This is managed by ic-stepper."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "last-step",
                "reflect": false
            },
            "lastStepNum": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "The step number of the final step. This is managed by ic-stepper."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "last-step-num",
                "reflect": false
            },
            "nextStepHeading": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "The name of the next step. This is managed by ic-stepper."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "next-step-heading",
                "reflect": false
            },
            "progress": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "The progress of the next step, calculated by dividing the current step number by the total number of steps. This is managed by ic-stepper."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "progress",
                "reflect": false
            },
            "stepNum": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "The step number, managed by ic-stepper."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "step-num",
                "reflect": false
            },
            "status": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcStepStatuses",
                    "resolved": "\"optional\" | \"required\" | undefined",
                    "references": {
                        "IcStepStatuses": {
                            "location": "import",
                            "path": "./ic-step.types",
                            "id": "src/components/ic-step/ic-step.types.ts::IcStepStatuses"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The status of the step. Use this prop to display a status message on the step if it is required or optional."
                },
                "getter": false,
                "setter": false,
                "attribute": "status",
                "reflect": false
            },
            "subheading": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Additional information about the step. Use this prop to override the default step status messaging displayed when selecting a step type or step status."
                },
                "getter": false,
                "setter": false,
                "attribute": "subheading",
                "reflect": false
            },
            "heading": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The title of the step within the stepper."
                },
                "getter": false,
                "setter": false,
                "attribute": "heading",
                "reflect": false
            },
            "theme": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcThemeMode",
                    "resolved": "\"dark\" | \"inherit\" | \"light\" | undefined",
                    "references": {
                        "IcThemeMode": {
                            "location": "import",
                            "path": "../../utils/types",
                            "id": "src/utils/types.ts::IcThemeMode"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "Sets the theme color to the dark or light theme color. \"inherit\" will set the color based on the system settings or ic-theme component."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "theme",
                "reflect": false,
                "defaultValue": "\"inherit\""
            },
            "variant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcStepVariants",
                    "resolved": "\"compact\" | \"default\"",
                    "references": {
                        "IcStepVariants": {
                            "location": "import",
                            "path": "./ic-step.types",
                            "id": "src/components/ic-step/ic-step.types.ts::IcStepVariants"
                        }
                    }
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "The variant of the step. This is managed by ic-stepper."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "variant",
                "reflect": false
            },
            "type": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcStepTypes",
                    "resolved": "\"active\" | \"completed\" | \"current\" | \"disabled\" | undefined",
                    "references": {
                        "IcStepTypes": {
                            "location": "import",
                            "path": "./ic-step.types",
                            "id": "src/components/ic-step/ic-step.types.ts::IcStepTypes"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The state of the step within the stepper."
                },
                "getter": false,
                "setter": false,
                "attribute": "type",
                "reflect": false,
                "defaultValue": "\"active\""
            }
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "type",
                "methodName": "typeChangeHandler"
            }];
    }
}
//# sourceMappingURL=ic-step.js.map
