import { Host, h, } from "@stencil/core";
export class TabPanel {
    constructor() {
        /**
         * @internal If `true`, the tab panel will be displayed.
         */
        this.active = false;
        /**
         * @internal Determines whether black variant of the tabs should be displayed.
         */
        this.monochrome = false;
        /** @internal Determines whether the light or dark variant of the tabs should be displayed. */
        this.theme = "inherit";
    }
    connectedCallback() {
        this.tabPanelCreated.emit(this.el);
    }
    render() {
        const { active, theme } = this;
        return (h(Host, { key: 'b5bfad1dbd94c81d889c5cb1e5dabadece967655', class: {
                [`ic-theme-${theme}`]: theme !== "inherit",
                "ic-tab-panel-hidden": !active,
            }, role: "tabpanel", "aria-hidden": `${!active}` }, h("div", { key: 'a1032b06a9103331d74a35a9c4bd1a47a63d3335' }, h("slot", { key: '5c8c7c9bbbc6573e9e3a05224cb50ef36740c81c' }))));
    }
    static get is() { return "ic-tab-panel"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["ic-tab-panel.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["ic-tab-panel.css"]
        };
    }
    static get properties() {
        return {
            "active": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "If `true`, the tab panel will be displayed."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "active",
                "reflect": false,
                "defaultValue": "false"
            },
            "monochrome": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "Determines whether black variant of the tabs should be displayed."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "monochrome",
                "reflect": false,
                "defaultValue": "false"
            },
            "panelId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "The shared ID that links the panel and tab."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "panel-id",
                "reflect": true
            },
            "selectedTab": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "The shared ID of the currently selected tab."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "selected-tab",
                "reflect": false
            },
            "tabPosition": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "The position of the tab panel inside the tabs array in context."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "tab-position",
                "reflect": true
            },
            "theme": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcThemeMode",
                    "resolved": "\"dark\" | \"inherit\" | \"light\" | undefined",
                    "references": {
                        "IcThemeMode": {
                            "location": "import",
                            "path": "../../utils/types",
                            "id": "src/utils/types.ts::IcThemeMode"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "Determines whether the light or dark variant of the tabs should be displayed."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "theme",
                "reflect": false,
                "defaultValue": "\"inherit\""
            }
        };
    }
    static get events() {
        return [{
                "method": "tabPanelCreated",
                "name": "tabPanelCreated",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "Emitted when a tab panel is dynamically created."
                        }],
                    "text": ""
                },
                "complexType": {
                    "original": "HTMLIcTabPanelElement",
                    "resolved": "HTMLIcTabPanelElement",
                    "references": {
                        "HTMLIcTabPanelElement": {
                            "location": "global",
                            "id": "global::HTMLIcTabPanelElement"
                        }
                    }
                }
            }, {
                "method": "tabPanelRemoved",
                "name": "tabPanelRemoved",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "Emitted when a tab panel is unmounted."
                        }],
                    "text": ""
                },
                "complexType": {
                    "original": "void",
                    "resolved": "void",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=ic-tab-panel.js.map
