import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { i as isSlotUsed, o as onComponentRequiredPropUndefined, f as renderDynamicChildSlots } from './helpers.js';
import { d as defineCustomElement$2 } from './ic-typography2.js';

const icEmptyStateCss = ":host{gap:var(--ic-space-xs);padding:var(--ic-space-xs)}:host,.action-area{display:flex;flex-direction:column}.action-area{gap:var(--ic-space-md)}:host ::slotted(svg),:host ::slotted(img){border-radius:var(--ic-space-xxs)}:host(.ic-empty-state-right),:host(.ic-empty-state-right) .action-area{align-items:flex-end;text-align:right}:host(.ic-empty-state-center),:host(.ic-empty-state-center) .action-area{align-items:center;text-align:center}:host(.image-medium) ::slotted(svg),:host(.image-medium) ::slotted(img){height:calc(3 * var(--ic-space-lg)) !important;width:calc(3 * var(--ic-space-lg)) !important}:host(.image-small) ::slotted(svg),:host(.image-small) ::slotted(img){height:var(--ic-space-xxl) !important;width:var(--ic-space-xxl) !important}:host(.image-large) ::slotted(svg),:host(.image-large) ::slotted(img){height:calc(4 * var(--ic-space-xl)) !important;width:calc(4 * var(--ic-space-xl)) !important}::slotted([slot=\"heading\"]),.empty-state-heading{--ic-typography-color:var(--ic-empty-state-title)}::slotted([slot=\"subheading\"]),.empty-state-subheading{--ic-typography-color:var(--ic-empty-state-subtitle)}::slotted([slot=\"body\"]),.empty-state-body{--ic-typography-color:var(--ic-empty-state-body)}";
const IcEmptyStateStyle0 = icEmptyStateCss;

const EmptyState = /*@__PURE__*/ proxyCustomElement(class EmptyState extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.hostMutationObserver = null;
        /**
         * The alignment of the empty state container.
         */
        this.aligned = "left";
        /**
         * The size of the image or icon used in the image slot.
         */
        this.imageSize = "medium";
        /**
         * Sets the theme color to the dark or light theme color. "inherit" will set the color based on the system settings or ic-theme component.
         */
        this.theme = "inherit";
    }
    disconnectedCallback() {
        var _a;
        (_a = this.hostMutationObserver) === null || _a === void 0 ? void 0 : _a.disconnect();
    }
    componentDidLoad() {
        !isSlotUsed(this.el, "heading") &&
            onComponentRequiredPropUndefined([{ prop: this.heading, propName: "heading" }], "Empty State");
        this.hostMutationObserver = new MutationObserver((mutationList) => renderDynamicChildSlots(mutationList, ["image", "actions"], this));
        this.hostMutationObserver.observe(this.el, {
            childList: true,
        });
    }
    render() {
        const { aligned, body, maxLines, heading, imageSize, subheading, theme } = this;
        return (h(Host, { key: '995486bbd0f1f633fec42b3b01b13c4d8df5ea70', class: {
                [`ic-empty-state-${aligned}`]: true,
                [`image-${imageSize}`]: isSlotUsed(this.el, "image"),
                [`ic-theme-${theme}`]: theme !== "inherit",
            } }, isSlotUsed(this.el, "image") && h("slot", { key: 'd8fc4fccad70f8c76f3d2f3684d941369c005418', name: "image" }), h("div", { key: '29923eb7b5f47ba5d6bfac9864f69c3a0b233fc9' }, h("slot", { key: '89ec9f7dde4c6e726840ba32e3b93374d28ad1d1', name: "heading" }, h("ic-typography", { key: 'a7bd4e5f9c7ad89032039b41c72a8a3ac44ee0c4', variant: "h4", class: "empty-state-heading" }, heading)), h("slot", { key: 'b23c53436c1ca4c5c5c4e38c59bd2112f17496fe', name: "subheading" }, h("ic-typography", { key: 'da22a6520f4a9de48708f82ea3a9bde7e978e06a', variant: "subtitle-small", class: "empty-state-subheading" }, subheading)), h("slot", { key: 'f86fc11ab34c45122ff6a24ad13a57f8ed925865', name: "body" }, h("ic-typography", { key: 'd978a50aa34e841b0d7726fa8b0d808734e00ffc', maxLines: maxLines, class: "empty-state-body" }, body))), isSlotUsed(this.el, "actions") && (h("div", { key: 'bb3d3484cbe367efea17a3809a50a3089a135251', class: "action-area" }, h("slot", { key: 'edb8ba0fc8813c0dd21f993e43fa788a9eb8074e', name: "actions" })))));
    }
    get el() { return this; }
    static get style() { return IcEmptyStateStyle0; }
}, [1, "ic-empty-state", {
        "aligned": [1],
        "body": [1],
        "maxLines": [2, "max-lines"],
        "heading": [1],
        "imageSize": [1, "image-size"],
        "subheading": [1],
        "theme": [1]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["ic-empty-state", "ic-typography"];
    components.forEach(tagName => { switch (tagName) {
        case "ic-empty-state":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, EmptyState);
            }
            break;
        case "ic-typography":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}

const IcEmptyState = EmptyState;
const defineCustomElement = defineCustomElement$1;

export { IcEmptyState, defineCustomElement };

//# sourceMappingURL=ic-empty-state.js.map