import { EventEmitter } from "../../stencil-public-runtime";
import { IcBrandForegroundNoDefault, IcColor, IcEmphasisType, IcSizes, IcThemeMode } from "../../utils/types";
/**
 * @slot icon - Content will be rendered at the start of the chip.
 * @slot badge - Badge component overlaying the top right of the chip.
 */
export declare class Chip {
    private buttonEl?;
    el: HTMLIcChipElement;
    foregroundColor: IcBrandForegroundNoDefault | null;
    hovered: boolean;
    visible: boolean;
    /**
     * The custom chip colour. This will override the theme colour.
     * Can be a hex value e.g. "#ff0000", RGB e.g. "rgb(255, 0, 0)", or RGBA e.g. "rgba(255, 0, 0, 1)".
     */
    customColor?: IcColor;
    customColorHandler(): void;
    /**
     * If `true`, the chip will appear disabled.
     */
    disabled: boolean;
    watchDisabledHandler(): void;
    /**
     * If `true`, the chip will have a close button at the end to dismiss it.
     */
    dismissible: boolean;
    /**
     * The text in the dismiss button tooltip and aria label. Makes the user aware of the action resulting from clicking the 'Dismiss chip' button.
     */
    dismissLabel: string;
    /**
     * The text rendered within the chip.
     */
    label: string;
    /**
     * The size of the chip.
     */
    size: IcSizes;
    /**
     * Sets the chip to the dark or light theme colors. "inherit" will set the color based on the system settings or ic-theme component.
     * Setting the "customColor" prop will override this.
     */
    theme: IcThemeMode;
    /**
     * If `true`, the outlined variant of chip will have a transparent background rather than the theme defined color.
     */
    transparentBackground: boolean;
    /**
     * The emphasis of the chip.
     */
    variant: IcEmphasisType;
    /**
     * Is emitted when the user dismisses the chip.
     */
    icDismiss: EventEmitter<void>;
    componentWillLoad(): void;
    componentDidLoad(): void;
    handleClick(): void;
    /**
     * Sets focus on the chip.
     */
    setFocus(): Promise<void>;
    private dismissAction;
    private mouseEnterHandler;
    private mouseLeaveHandler;
    render(): any;
}
