import { IcBrand, IcThemeMode } from "../../utils/types";
/**
 * @slot router-item - Handle routing by nesting your routes in this slot.
 */
export declare class Link {
    private inheritedAttributes;
    private routerSlot;
    private hostMutationObserver;
    el: HTMLIcLinkElement;
    /**
     * If `true`, the user can save the linked URL instead of navigating to it. If the value is a string, it will be used as the filename for the download.
     */
    download?: string | boolean;
    /**
     * The URL that the link points to.
     */
    href?: string;
    /**
     * The human language of the linked URL.
     */
    hreflang?: string;
    /**
     * If `true`, the link will display as black in the light theme, and white in the dark theme.
     */
    monochrome?: boolean;
    /**
     * How much of the referrer to send when following the link.
     */
    referrerpolicy?: ReferrerPolicy;
    /**
     * The relationship of the linked URL as space-separated link types.
     */
    rel?: string;
    /**
     * The place to display the linked URL, as the name for a browsing context (a tab, window, or iframe).
     */
    target?: string;
    /**
     * Sets the theme color to the dark or light theme color. "inherit" will set the color based on the system settings or ic-theme component.
     */
    theme?: IcThemeMode;
    componentWillLoad(): void;
    componentDidLoad(): void;
    disconnectedCallback(): void;
    brandChangeHandler({ detail }: CustomEvent<IcBrand>): void;
    /**
     * Sets focus on the link.
     */
    setFocus(): Promise<void>;
    private updateTheme;
    private hasRouterSlot;
    private hostMutationCallback;
    private setDownloadAttribute;
    render(): any;
}
